var Helper = {
	
	show: function( id, visible ) {
		var element = document.getElementById( id );
		if ( element == null ) {
			return;
		}
		
		var className = element.className;
		if ( className == null )
			className = "";
			 
		if ( visible ) {
			className = className.replace( / ?hidden/, "" );
		} else {
			if ( className.indexOf( "hidden") == -1 ) {
				if ( className.length > 0 )
					className += " ";
				
				className += "hidden";												
			}					
		}
		
		element.className = className;  		
	},
	
	showUsingElement: function( element, visible ) {
		if ( element == null ) {
			return;
		}
		
		var className = element.className;
		if ( className == null )
			className = "";
			 
		if ( visible ) {
			className = className.replace( / ?hidden/, "" );
		} else {
			if ( className.indexOf( "hidden") == -1 ) {
				if ( className.length > 0 )
					className += " ";
				
				className += "hidden";												
			}					
		}
		
		element.className = className;  		
	},
	
	activate: function( id, activated ) {
		var element = document.getElementById( id );
		if ( element == null ) {
			return;
		}

		var className = element.className;
		if ( className == null )
			className = "";
			 
		if ( !activated ) {
			className = className.replace( / ?activated/, "" );
		} else {
			if ( className.indexOf( "activated") == -1 ) {
				if ( className.length > 0 )
					className += " ";
				
				className += "activated";												
			}					
		}
		
		element.className = className;  		
	},
	
	createTableHeader: function( title ) {
		return '<tr><th colspan="2">' + title + '</th></tr>';
	},
	
	createStatusRow: function( imgUrl, name, status, time, source ) {
		// We need to set the width of the row so that long words or links don't
		// break our structure.
		var statusWidth = Helper.getScreenSize().width;
		if ( Helper.isLargeScreen() ) {
			var menuWidth = Helper.isLandscape() ? 84 : 0; /* If we are in landscape take menu width away - wich is 84px with padding */
			statusWidth = statusWidth - 48 - 10 - 10 - menuWidth; /* 48 is image width, 10 is for image padding, 10 is for status div padding */
		} else {
			statusWidth = statusWidth - 24 - 6 - 10; /* 24 is image width, 6 is for image padding, 10 is for status div padding */
		}
		 
		var rowString = '<tr class="tweet">' +
      		'<td class="image"><img src="' + imgUrl + '" alt="Image"></td>' +
            '<td class="tweet_content">' +
				'<div style="width: ' + statusWidth + 'px;" class="status">' +
                '<span class="name">' + name + '</span> ' +
            	status +
                '</div>';
		if ( time != null && source != null ) {
			rowString += '<div class="ago">' + time +
				'<span class="from">' + source + '</span>' +
				'</div>';
		}
		rowString += '</td></tr>';
			
		return rowString;
	},

	getScreenSize: function() {
		var height = window.innerHeight;
		var width = window.innerWidth;
			
		return {
			width: width,
			height: height
		};
	},

	isLandscape: function() {
		var size = this.getScreenSize();
		return ( size.width > size.height );	
	},

	isLargeScreen: function() {
		var size = this.getScreenSize();
		return ( size.height > Helper.SMALL_SCREEN_TRESHOLD );
	},

	applyCorrectStyles: function() {
		var largeScreen = Helper.isLargeScreen();
		
		document.styleSheets[0].disabled = !largeScreen;
		document.styleSheets[1].disabled = largeScreen;
	},
	
	isMiniViewMode: function() {
		var size = this.getScreenSize();
		return ( size.height < Helper.MINI_VIEW_TRESHOLD );
	},
	
	handleCustomControlClick: function( control ) {
		control.parentNode.className = control.checked ? "checked" : "";
	}
}

Helper.SMALL_SCREEN_TRESHOLD = 320;
Helper.MINI_VIEW_TRESHOLD = 150;
